<?php

namespace Payshop\Core\Action;

use Payshop\Core\Gateway\SDK\PayshopSDKClientFactory;

class CreatePayment
{
    /**
     * @var PayshopSDKClientFactory
     */
    private PayshopSDKClientFactory $payshopSDKClientFactory;

    /**
     * CreatePayment constructor.
     * 
     * @param PayshopSDKClientFactory $payshopSDKClientFactory
     */
    public function __construct(
        PayshopSDKClientFactory $payshopSDKClientFactory
    )
    {
        $this->payshopSDKClientFactory = $payshopSDKClientFactory;
    }

    /**
     * Create payment on Payshop
     *
     * @param string $instrumentId
     * @param float $effectiveValue
     * @return string
     */
    public function execute($instrumentId, float $effectiveValue): string
    {
        $payshopClient = $this->payshopSDKClientFactory->getInstance();

        $response = $payshopClient->createPayment([
            'instrument' => $instrumentId,
            'amount' => $effectiveValue,
            'currency' => 'EUR',
        ]);

        $this->validateResponseStatus($response);
        $this->validatePaymentSuccess($response);

        return $response['response']['id'];
    }

    /**
     * Validate response status
     * 
     * @param array $response
     * @return void
     * @throws Exception
     */
    private function validateResponseStatus(array $response): void
    {
        $message = __('Error on send confirmation payment to Payshop. Please, try again');

        if ($response['status'] != 201) {
            throw new \Exception($message);
        }
    }

    /**
     * Validate payment success
     * 
     * @param array $response
     * @return void
     * @throws Exception
     */
    private function validatePaymentSuccess(array $response): void
    {
        $message = __('Payment confirmation not accepted from Payshop');

        $successful = $response['response']['success'];
        $statusSuccess = $response['response']['status'] == 'success';

        if (!$successful || !$statusSuccess) {
            throw new \Exception($message);
        }
    }
}