<?php

namespace Payshop\Core\Controller\Adminhtml\Card;

use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Payshop\Core\Action\ConfirmCardPayment;
use Magento\Framework\App\RequestInterface;
use Magento\Framework\Controller\Result\JsonFactory;

class ConfirmPayment extends Action
{
    /**
     * @var RequestInterface
     */
    private RequestInterface $request;

    /**
     * @var JsonFactory
     */
    private JsonFactory $resultJsonFactory;

    /**
     * @var ConfirmCardPayment
     */
    private ConfirmCardPayment $confirmCardPayment;

    /**
     * @param Context $context
     * @param RequestInterface $request
     * @param JsonFactory $resultJsonFactory
     * @param ConfirmCardPayment $confirmCardPayment
     */
    public function __construct(
        Context $context,
        RequestInterface $request,
        JsonFactory $resultJsonFactory,
        ConfirmCardPayment $confirmCardPayment
    ) {
        parent::__construct($context);
        $this->request = $request;
        $this->resultJsonFactory = $resultJsonFactory;
        $this->confirmCardPayment = $confirmCardPayment;
    }
   
    /**
     * Confirm efetive value of order via Ajax
     * 
     * @return \Magento\Framework\Controller\Result\Json
     */
    public function execute()
    {
        $resultJson = $this->resultJsonFactory->create();

        try {
            $orderId = $this->request->getParam('orderid');
            $efectiveOrderValue = $this->request->getParam('effective_value', 0.0);

            $this->confirmCardPayment->execute($orderId, $efectiveOrderValue);

            return $resultJson->setData(['success' => true]);
        } catch (\Throwable $th) {
            return $resultJson
                    ->setHttpResponseCode(400)
                    ->setData(['message' => $th->getMessage()]);
        }
    }
}