<?php

namespace Payshop\Core\Gateway\SDK;

use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Payment\Gateway\ConfigInterface;

class PayshopSDKClientFactory
{
    /**
     * @var ConfigInterface
     */
    private $credentials;

    public function __construct(
        ConfigInterface $credentials
    ) {
        $this->credentials = $credentials;
    }

    /**
     * Instanciete the class
     *
     * @return \PayshopClient
     */
    public function getInstance()
    {
        require_once 'PayshopClientSingleton.php';

        return \PayshopClientSingleton::getInstance(
            $this->getPublicKey(),
            $this->getSecretKey(),
            $this->getAccountId(),
            $this->isProduction()
        );
    }

    /**
     * Check if the module is in production mode
     *
     * @return boolean
     */
    public function isProduction()
    {
        $environment = $this->credentials->getValue(
            'environment', 
            ScopeConfigInterface::SCOPE_TYPE_DEFAULT
        );

        return $environment == 'production';
    }

    /**
     * Get public key based on the environment
     *
     * @return string
     */
    public function getPublicKey()
    {
        return $this->credentials->getValue(
            self::isProduction() ? 'public_key_production' : 'public_key_test',
            ScopeConfigInterface::SCOPE_TYPE_DEFAULT
        );
    }

    /**
     * Get secret key based on the environment
     *
     * @return string
     */
    private function getSecretKey()
    {
        return $this->credentials->getValue(
            self::isProduction() ? 'private_key_production' : 'private_key_test',
            ScopeConfigInterface::SCOPE_TYPE_DEFAULT
        );
    }

    /**
     * Get account ID based on the environment
     *
     * @return string
     */
    private function getAccountId()
    {
        return $this->credentials->getValue(
            self::isProduction() ? 'account_id_production' : 'account_id_test',
            ScopeConfigInterface::SCOPE_TYPE_DEFAULT
        );
    }
}