<?php

namespace Payshop\Core\Helper;

use Magento\Payment\Gateway\ConfigInterface;

class PayshopConfigurationsComposite
{
    /**
     * @var ConfigInterface
     */
    private ConfigInterface $card;

    /**
     * @var ConfigInterface
     */
    private ConfigInterface $mbway;

    /**
     * @var ConfigInterface
     */
    private ConfigInterface $credentials;

    /**
     * @var ConfigInterface
     */
    private ConfigInterface $payshopReference;

    /**
     * @var ConfigInterface
     */
    private ConfigInterface $multibancoReference;

    /**
     * PayshopConfigurationsComposite constructor.
     * 
     * @param ConfigInterface $card
     * @param ConfigInterface $mbway
     * @param ConfigInterface $credentials
     * @param ConfigInterface $payshopReference
     * @param ConfigInterface $multibancoReference
     */
    public function __construct(
        ConfigInterface $card,
        ConfigInterface $mbway,
        ConfigInterface $credentials,
        ConfigInterface $payshopReference,
        ConfigInterface $multibancoReference
        ) {
        $this->card = $card;
        $this->mbway = $mbway;
        $this->credentials = $credentials;
        $this->payshopReference = $payshopReference;
        $this->multibancoReference = $multibancoReference;
    }

    /**
     * Get card configurations
     * 
     * @return ConfigInterface
     */
    public function getCard()
    {
        return $this->card;
    }

    /**
     * Get MBWay configurations
     * 
     * @return ConfigInterface
     */
    public function getMBWay()
    {
        return $this->mbway;
    }

    /**
     * Get general configurations
     * 
     * @return ConfigInterface
     */
    public function getCredentials()
    {
        return $this->credentials;
    }

    /**
     * Get payshop reference configurations
     * 
     * @return ConfigInterface
     */
    public function getPayshopRefence()
    {
        return $this->payshopReference;
    }

    /**
     * Get multinco reference configurations
     * 
     * @return ConfigInterface
     */
    public function getMultibancoReference()
    {
        return $this->multibancoReference;
    }
}