<?php

namespace Payshop\Core\Observer;

use Magento\Sales\Model\Order;
use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Sales\Model\Spi\OrderResourceInterface;

class AfterPlaceOrder implements ObserverInterface
{
    /**
     * @var Order
     */
    private Order $order;
    
    /**
     * @var OrderResourceInterface
     */
    private OrderResourceInterface $orderResource;

    /**
     * AfterPlaceOrder constructor.
     * 
     * @param Order $order
     * @param OrderResourceInterface $orderResource
     */
    public function __construct(
        Order $order,
        OrderResourceInterface $orderResource
    ) {
        $this->order = $order;
        $this->orderResource = $orderResource;
    }

    /**
     * @inheritDoc
     */
    public function execute(Observer $observer)
    {
        $orderIncrementId = $observer->getEvent()->getOrder()->getIncrementId();
        $orderModel = $this->order->loadByIncrementId($orderIncrementId);
        $paymentMethod = $orderModel->getPayment()->getMethod();

        if ($paymentMethod == 'payshop_card') {
           return;
        } 

        $orderModel->setState(\Magento\Sales\Model\Order::STATE_PENDING_PAYMENT);
        $orderModel->setStatus(\Magento\Sales\Model\Order::STATE_PENDING_PAYMENT);

        $this->orderResource->save($orderModel);
    }
}
