<?php

namespace Payshop\Core\Validation;

class Card
{
    /**
     * Validate Card Informations
     * 
     * @param array $data
     * @return void
     * @throws \Exception
     */
    public static function validate(array $data): void
    {
        self::validateCardNumber($data['number']);
        self::validateCardHolderName($data['name']);
        self::validateCardExpiryMonth($data['expiration_month']);
        self::validateCardExpiryYear($data['expiration_year']);
        self::validateCardCvv($data['cvc']);
    }

    /**
     * Validate Card Number
     * 
     * @param string $cardNumber
     * @return bool
     * @throws \Exception
     */
    private static function validateCardNumber(string $cardNumber): bool
    {
        if (!isset($cardNumber) || empty($cardNumber)) {
            throw new \Exception("100001");
        }

        $cardNumber = preg_replace('/\s+/', '', $cardNumber);
        $cardNumber = strrev($cardNumber);
        $numberArray = str_split($cardNumber);
        $sum = 0;
        foreach ($numberArray as $key => $value) {
            if ($key % 2 != 0) {
                $value *= 2;
                if ($value > 9) {
                    $value -= 9;
                }
            }
            $sum += $value;
        }
        if ($sum % 10 == 0) {
            return true;
        }
        
        throw new \Exception("100001");
    }

    /**
     * Validate Card Holder Name
     * 
     * @param string $cardHolderName
     * @return bool
     * @throws \Exception
     */
    private static function validateCardHolderName(string $cardHolderName): bool
    {
        if (!isset($cardHolderName) || empty($cardHolderName)) {
            throw new \Exception("100003");
        }

        if (preg_match('/^[a-zA-Z ]+$/', $cardHolderName)) {
            return true;
        }
        
        throw new \Exception("100003");
    }

    /**
     * Validate Card Expiry Month
     * 
     * @param string $cardExpiryMonth
     * @return bool
     * @throws \Exception
     */
    private static function validateCardExpiryMonth(string $cardExpiryMonth): bool
    {
        if (!isset($cardExpiryMonth) || empty($cardExpiryMonth)) {
            throw new \Exception("100004");
        }

        if (preg_match('/^[0-9]{1,2}$/', $cardExpiryMonth)) {
            return true;
        }
        
        throw new \Exception("100004");
    }

    /**
     * Validate Card Expiry Year
     * 
     * @param string $cardExpiryYear
     * @return bool
     * @throws \Exception
     */
    private static function validateCardExpiryYear(string $cardExpiryYear): bool
    {
        if (!isset($cardExpiryYear) || empty($cardExpiryYear)) {
            throw new \Exception("100005");
        }

        if (preg_match('/^[0-9]{4}$/', $cardExpiryYear)) {
            return true;
        }
        
        throw new \Exception("100005");
    }

    /**
     * Validate Card CVV
     * 
     * @param string $cardCvv
     * @return bool
     * @throws \Exception
     */
    private static function validateCardCvv(string $cardCvv): bool
    {
        if (!isset($cardCvv) || empty($cardCvv)) {
            throw new \Exception("100006");
        }

        if (preg_match('/^[0-9]{3}$/', $cardCvv)) {
            return true;
        }
        
        throw new \Exception("100006");
    }
}